@@ -25,7 +25,7 @@ if sys.version_info > (3, ):
 
 dna_bases = re.compile(r'([ACTGNactgnYRWSKMDVHBXyrwskmdvhbx]+)')
 
-__version__ = '0.5.4'
+__version__ = '0.5.5.2'
 
 
 class KeyFunctionError(ValueError):
@@ -335,9 +335,13 @@ class Faidx(object):
             # Only try to import Bio if we actually need the bgzf reader.
             try:
                 from Bio import bgzf
+                from Bio import __version__ as bgzf_version
+                from distutils.version import LooseVersion
+                if LooseVersion(bgzf_version) < LooseVersion('1.73'):
+                    raise ImportError
             except ImportError:
                 raise ImportError(
-                    "BioPython must be installed to read gzipped files.")
+                    "BioPython >= 1.73 must be installed to read block gzip files.")
             else:
                 self._fasta_opener = bgzf.open
                 self._bgzf = True
@@ -499,7 +503,7 @@ class Faidx(object):
 
     def build_index(self):
         try:
-            with self._fasta_opener(self.filename, 'r') as fastafile:
+            with self._fasta_opener(self.filename, 'rb') as fastafile:
                 with open(self.indexname, 'w') as indexfile:
                     rname = None  # reference sequence name
                     offset = 0  # binary offset of end of current line
@@ -508,10 +512,11 @@ class Faidx(object):
                     clen = None  # character line length
                     bad_lines = []  # lines > || < than blen
                     thisoffset = offset
-
+                    valid_entry = False
                     lastline = None
                     for i, line in enumerate(fastafile):
                         line_blen = len(line)
+                        line = line.decode()
                         line_clen = len(line.rstrip('\n\r'))
                         lastline = i
                         # write an index line
@@ -556,6 +561,12 @@ class Faidx(object):
                                 bad_lines.append((i, line_blen))
                             offset += line_blen
                             rlen += line_clen
+                    
+                    # check that we find at least 1 valid FASTA record
+                    if not valid_entry:
+                        raise FastaIndexingError(
+                            "The FASTA file %s does not contain a valid sequence. "
+                            "Check that sequence definition lines start with '>'." % self.filename)
 
                     # write the final index line, if there is one.
                     if lastline is not None:
@@ -667,7 +678,7 @@ class Faidx(object):
                     seq = ''
 
         if not internals:
-            return seq.replace('\n', '')
+            return seq.replace('\n', '').replace('\r', '')
         else:
             return (seq, locals())
 
@@ -709,14 +720,20 @@ class Faidx(object):
                 )
             elif len(seq) == len(file_seq) - internals['newlines_inside']:
                 line_len = internals['i'].lenc
+                if '\r\n' in file_seq:
+                    newline_char = '\r\n'
+                elif '\r' in file_seq:
+                    newline_char = '\r'
+                else:
+                    newline_char = '\n'
                 self.file.seek(internals['bstart'])
                 if internals['newlines_inside'] == 0:
                     self.file.write(seq.encode())
                 elif internals['newlines_inside'] > 0:
                     n = 0
-                    m = file_seq.index('\n')
+                    m = file_seq.index(newline_char)
                     while m < len(seq):
-                        self.file.write(''.join([seq[n:m], '\n']).encode())
+                        self.file.write(''.join([seq[n:m], newline_char]).encode())
                         n = m
                         m += line_len
                     self.file.write(seq[n:].encode())
@@ -796,7 +813,7 @@ class FastaRecord(object):
             raise
 
     def __iter__(self):
-        """ Construct a line-based iterator that respects the original line lengths. """
+        """ Construct a line-based generator that respects the original line lengths. """
         line_len = self._fa.faidx.index[self.name].lenc
         start = 0
         while True:
@@ -805,11 +822,11 @@ class FastaRecord(object):
                 yield self[start:end]
             else:
                 yield self[start:]
-                raise StopIteration
+                return
             start += line_len
 
     def __reversed__(self):
-        """ Reverse line-based iterator """
+        """ Reverse line-based generator """
         line_len = self._fa.faidx.index[self.name].lenc
         # have to determine last line length
         last_line = len(self) % line_len
@@ -822,7 +839,7 @@ class FastaRecord(object):
                 yield self[start:end][::-1]
             else:
                 yield self[:end][::-1]
-                raise StopIteration
+                return
             if end == len(self):  # first iteration
                 end -= last_line
             else:
